<template>
  <div class="bbsl-common-page">
    <div class="bbsl-table-search">
      <el-form v-model="queryParam" label-width="auto">
        <el-row :gutter="10">
          <el-col :span="5">
            <el-form-item label="供应商名称">
              <el-input clearable placeholder="请输入供应商名称" v-model="querys[0].value" />
            </el-form-item>
          </el-col>
          <el-col :span="5">
            <el-form-item label="联系人">
              <el-input clearable placeholder="请输入联系人" v-model="querys[1].value" />
            </el-form-item>
          </el-col>
          <el-col :span="5">
            <el-form-item label="联系电话">
              <el-input clearable placeholder="请输入联系电话" v-model="querys[2].value" />
            </el-form-item>
          </el-col>
          <el-col :span="4">
            <el-button type="primary" icon="el-icon-search" @click="handleSearch">搜索</el-button>
            <el-button icon="el-icon-refresh" @click="handleReset">重置</el-button>
          </el-col>
        </el-row>
      </el-form>
    </div>
    <div class="bbsl-table-content" ref="contentPanel">
      <div class="bbsl-btn-content" ref="btnPanel">
        <el-button icon="el-icon-plus" type="primary" @click="handleAdd">新增</el-button>
        <!-- <el-button icon="el-icon-sort" plain type="primary" @click="insortAdd"
          >排序保存</el-button
        > -->
        <el-popconfirm title="确定删除选中数据吗？" @confirm="handleDelete">
          <el-button slot="reference" :disabled="!multipleSelection.length" icon="el-icon-delete" type="danger"
            style="margin-left: 10px">删除</el-button>
        </el-popconfirm>
      </div>
      <el-table border size="mini" v-loading="loading" ref="multipleSelection" :data="tableData"
        :style="{ width: '100%' }" :max-height="tableMaxHeight" :cell-style="{ 'text-align': 'center' }"
        :header-cell-style="{ 'text-align': 'center' }" @row-dblclick="handleDbClick"
        @selection-change="handleSelectionChange">
        <el-table-column type="selection" width="55"></el-table-column>
        <el-table-column type="index" width="55" label="序号"></el-table-column>

        <el-table-column prop="name" label="供应商名称" show-overflow-tooltip></el-table-column>

        <el-table-column prop="linkMan" label="联系人" show-overflow-tooltip></el-table-column>

        <el-table-column prop="phone" label="联系电话" show-overflow-tooltip></el-table-column>

        <!-- <el-table-column
          
          
          prop="email"
          label="邮箱"
          show-overflow-tooltip
        ></el-table-column> -->
        <!-- <el-table-column
          
          prop="sn"
          label="排序号"
          show-overflow-tooltip
        >
          <template slot-scope="scope">
            <el-input-number
              size="mini"
              v-model="scope.row.sn"
              controls-position="right"
              @input="insort(scope.row.id, scope.row.sn)"
            >
            </el-input-number>
          </template>
</el-table-column> -->
        <el-table-column prop="createTime" label="创建时间" show-overflow-tooltip>
          <template v-slot="{ row }">
            {{ formatDate(row.createTime) }}
          </template>
        </el-table-column>

        <el-table-column prop="updateTime" label="修改时间" show-overflow-tooltip>
          <template v-slot="{ row }">
            {{ formatDate(row.updateTime) }}
          </template>
        </el-table-column>
      </el-table>
      <el-pagination align="right" background class="bbsl-pagination" ref="paginationPanel"
        @size-change="handleSizeChange" @current-change="handleCurrentChange" :current-page="queryParam.pageBean.page"
        :page-sizes="[20, 30, 40, 50]" :page-size="queryParam.pageBean.pageSize"
        layout="total, sizes, prev, pager, next, jumper" :total="total"></el-pagination>
    </div>
    <CmgtMaterialCustomFormDialog ref="formModal"></CmgtMaterialCustomFormDialog>
  </div>
</template>

<script>
import { TableMixin } from '@/mixins/tableMixin'
import dictUtils from '@/components/dict/DictSelectUtils.js'
import dictContracts from '@/components/dict/DictSelectUtils.js'

import CmgtMaterialCustomApi from '@/views/Manage/material/api/CmgtMaterialCustomApi'
import CmgtMaterialCustomFormDialog from '@/views/Manage/material/components/CmgtMaterialCustomFormDialog'

export default {
  name: 'CmgtMaterialCustomManage',
  components: {
    CmgtMaterialCustomFormDialog
  },
  mixins: [TableMixin],
  data() {
    return {
      sortList: {},
      url: {
        delete: '/manager/cmgtMaterialCustom/delete'
      },
      sorter: [
        {
          direction: 'ASC',
          property: 'sn_'
        }
      ],
      querys: [
        {
          group: 'main',
          operation: 'LIKE',
          parentGroup: '',
          property: 'name_',
          relation: 'AND',
          value: ''
        },
        {
          group: 'main',
          operation: 'LIKE',
          parentGroup: '',
          property: 'link_man_',
          relation: 'AND',
          value: ''
        },
        {
          group: 'main',
          operation: 'LIKE',
          parentGroup: '',
          property: 'phone_',
          relation: 'AND',
          value: ''
        }
      ],
      StshowFormDias: false,
      fuelTypes: []
    }
  },
  created() { },
  mounted() { },
  methods: {
    // 重置
    clearQuerys() {
      this.querys[0].value = ''
      this.querys[1].value = ''
      this.querys[2].value = ''
    },
    // 获取list
    loadData(page) {
      if (page) {
        this.queryParam.pageBean.page = page
      }
      this.loading = true
      this.tableData = []
      this.queryParam.sorter = this.sorter
      this.queryParam.querys = []
      if (this.querys[0].value) {
        this.queryParam.querys.push(this.querys[0])
      }
      if (this.querys[1].value) {
        this.queryParam.querys.push(this.querys[1])
      }
      if (this.querys[2].value) {
        this.queryParam.querys.push(this.querys[2])
      }
      CmgtMaterialCustomApi.loadCmgtMaterialCustom(this.queryParam, res => {
        console.log(res, 'res')
        this.total = res.total
        this.tableData = res.rows
        this.$set(this.tableData)
        this.loading = false
      })
    },
    //排序
    insort(id, num) {
      // console.log(id, num)
      this.sortList[id] = num
      // console.log(this.sortList)
    },
    // insortAdd() {
    //   //排序保存
    //   CmgtMaterialCustomApi.cmgtMaterialCustomManager(this.sortList).then(
    //     res => {
    //       // console.log(res)
    //       this.loadData()
    //     }
    //   )
    // },
    // 修改
    handleUpdate(row) {
      console.log(row.id)
      this.$refs.formModal.Update(row)
    },
    // 关联设备
    // handleClick(item) {
    //   console.log(item.id)
    //   this.StshowFormDias = true
    // },
    closeStshowForm() {
      this.StshowFormDias = false
    }
  }
}
</script>
<style lang="scss" scoped>
.type-tag {
  margin: 0 2px;
}
</style>
